# servicestack-python
Python ServiceStack Client

## Conda build
Ensure you have conda installed.
- Install conda-build using `conda install conda-build`.
- Add conda-forge as channel using `conda config --add channels conda-forge`
- On root directory run `conda build .`
